/* ========================================================================= */
/* HELPERS ================================================================= */
/* ========================================================================= */

getDevice = function() {
	return (
		window.getComputedStyle(
	    	document.querySelector('html'), ':before'
		).getPropertyValue('content')
	);
};

trimInput = function(value) {
	return value.replace(/^\s*|\s*$/g, '');
};

/* ========================================================================= */
/* FUNCTIONS =============================================================== */
/* ========================================================================= */
var siteHandler = {
	/**
	 * Carga un template con los datos que recibe como parámetro.
	 *
	 * @param  {String}   name    	- Nombre del fichero .hbs donde se encuentra el template
	 * @param  {String}   where   	- Selector CSS donde vamos a insertar el template
	 * @param  {Object}	  context	- Objeto con los datos que va a utilizar el template
	 * @param  {Boolean}  append  	- Si es true inserta el template al final de un contenedor para no borrar su contenido
	 * @param  {Function} callback  - Función de callback
	 */
	loadTemplate: function(name, where, context, append, func) {
		var location = where || '#' + name,
			data = context,
			template = JST['app/templates/' + name + '.hbs'],
			html = template(data),
			callback = func;

		if (append)
			$(location).append(html);
		else
			document.querySelector(location).innerHTML = html;
		if (func)
			callback();
	},
	/**
	 * Establece los eventos de la app
	 */
	setEvents: {
		// activamos la pantalla principal (caracteristicas + ficha)
		activePrincipal: function(e){
			// reiniciamos eventos
			$('.area').off('click');

			// iterate through area objects to asign click event for modals
			_.each($('.area'), function(area, index) {
				 $(area).off('click').on('click', function(event) {
				 	event.preventDefault();
			 		siteHandler.loadTemplate($(area).data('area'),'#nucleusModal .modal-body');
				 	$('#nucleusModal').modal();
				 });
			});

			$('.btn-1').off('click').on('click', function(){
				var $graphs = $('.graph-wrapper'),
				    $elements = $('.s-e'),
				    $bars = $('.bars');
				//se añade la clase playing para "bloquear" el evento.
				if (!$('.btn-1').hasClass('playing')){
					$('.btn-1 .fa').toggleClass('fa-plus-circle fa-minus-circle');
					$('.btn-1').addClass('playing');
					$graphs.addClass('animated fadeIn').show();
					//ocultamos todos los elementos del size (size-elements + size-labels)
					$elements.hide();
					$bars.removeClass('expanded');

					_.each($elements, function(num, index, list){
						// a cada elemento de la gráfica le asignamos un timeOut para mostrarlos uno a uno
						setTimeout(function() {
						    $('.graph-element-'+(index+1)).addClass('animated fadeIn').show();
						}, 1000*(index+1));
					});

					_.each($bars, function(num, index, list){
						// a cada elemento de la gráfica le asignamos un timeOut para mostrarlos uno a uno
						setTimeout(function() {
						    $('.bars-'+(index+1)).addClass('expanded');
						}, 750*(index+1));
					});
				}
				else {
					$graphs.removeClass('fadeIn').addClass('fadeOut');
					setTimeout(function() {
						$graphs.animate({height: "0px"}, 500, function(){
							$graphs.hide().removeClass('fadeOut').css({'height':'auto'});
						})
						$('.btn-1').removeClass('playing');
						$('.btn-1 .fa').toggleClass('fa-plus-circle fa-minus-circle');
					}, 700);
				}
			});

			$('.island-zone').off('click').on('click', function(event) {
				/* Act on the event */
				$marker = $(this).find('.data-marker');

				// if is not visible
				if (!$marker.is(':visible')) {
					$marker.addClass('animated fadeInDown').show();
				}
				else {
					$marker.hide();
				}
			});

			$('.info-pic').off('click').on('click', function(event) {
				event.preventDefault();
				/* Act on the event */
				var $parent = $(event.currentTarget).parent(),
					$p = $parent.find('p'),
					$header = $parent.find('h3');

				if ($p.is(':visible')){
					$p.hide().removeClass('fadeIn');
					$header.hide().removeClass('fadeIn');
				}
				else {
					$p.addClass('fadeIn').show();
					$header.addClass('fadeIn').show();
				}
			});
		},
		activeLegend: function() {
			$('#curtainIcon').on('click', function(event) {
				event.preventDefault();
				$(this).find('i').toggleClass('fa-search-plus fa-search-minus');
				/* Act on the event */
				$('.legend-wrapper').toggleClass('closed');
			});
			$('#infoIcon').on('click', function(event) {
		        event.preventDefault();
		        event.stopPropagation();
		        /* Act on the event */
		        siteHandler.loadTemplate($(this).data('modal'),'#nucleusModalInfo .modal-body');
	            $('#nucleusModalInfo').modal();
	      	});
		}, centerModals: function(){
				function modalCenter(){
				$('.modal').each(function(i){
					$clone = $(this).clone().css('display', 'block').appendTo('body');
					var top = Math.round(($clone.height() - $clone.find('.modal-content').height()) / 2);
					top = top > 0 ? top : 0;
					$clone.remove();
					$(this).find('.modal-content').css("margin-top", top);
				});
			};
			$('.modal').on('show.bs.modal', modalCenter);
			$(window).on('resize', modalCenter);
		},
		stopVideo: function(){
			$('.modal').on('hidden.bs.modal', function (e) {
			  $('.modal video').attr("src", $(".modal video").attr("src"));
			});
		}
	},
	init: function() {
		//load template layout (header, grid, and site-canvas)
		this.loadTemplate('layout', '#mainWrapper', null, false, function(){
			siteHandler.loadTemplate('main');
			siteHandler.setEvents.activePrincipal();
			siteHandler.setEvents.activeLegend();
			siteHandler.setEvents.centerModals();
			siteHandler.setEvents.stopVideo();
		});
	}
};

siteHandler.init();
